@@ -24,20 +24,25 @@ use Getopt::Long;
 use Common::Log;
 
 sub commonOptions {
-	# default to 'info' unless there's a environment variable
-	# or a commandline arg
-	my($logLevel) = $ENV{'CRICKET_LOG_LEVEL'};
-	$logLevel = 'info' unless defined($logLevel);
+    # default to 'info' unless there's a environment variable
+    # or a commandline arg
+    my($logLevel, $base);
+    $logLevel = $Common::global::gLogLevel if $Common::global::gLogLevel;
+    $logLevel = $ENV{'CRICKET_LOG_LEVEL'} if $ENV{'CRICKET_LOG_LEVEL'};
+    $logLevel ||= "info";
 
-	$ENV{'HOME'} = '' unless (defined($ENV{'HOME'})); 
-	my($base) = "$ENV{'HOME'}/cricket-config";
+    GetOptions( "loglevel:s" => \$logLevel,
+                "base:s" => \$base, @_);
 
-	GetOptions( "loglevel:s" => \$logLevel, 
-				"base:s" => \$base, @_);
-
-	Common::Log::setLevel($logLevel);
-	$Common::global::gConfigRoot = $base;
+    $Common::global::gConfigRoot = $base if $base;
+    Common::Log::setLevel($logLevel);
 }
 
 1;
 
+# Local Variables:
+# mode: perl
+# indent-tabs-mode: nil
+# tab-width: 4
+# perl-indent-level: 4
+# End:
